@@ -321,13 +321,15 @@ class ClClientSyncLoginAction(Action):
         # отключить удалённый профиль
         {'name': 'domain_sync:umount_unix',
          'method': 'Client.umountRemoteUserRes(True,"unix","remote_profile")',
-         'depend': Tasks.hasnot('failed')
+         'depend': Tasks.hasnot('failed'),
+         'condition': lambda GetBool: not Get('cl_client_ignore_errors_set')
          },
         # отключить ресурсы в случае ошибки
         {'name': 'umount_remote_res',
          'message': __("Umounting user resources"),
          'method': 'Client.umountUserRes(desktop.ur_mount_dirs)',
-         'depend': Tasks.has('failed')
+         'depend': Tasks.has('failed'),
+         'condition': lambda GetBool: not Get('cl_client_ignore_errors_set')
          }
     ]
 
